//		Copyright © 1998–1999  Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
//		$Log: PersistentData.h,v $
//		Revision 1.3  1999/04/18 13:17:31  jjk
//		Get rid of virtual functions (Intel support).  Arrgh!
//
//		Revision 1.2  1999/04/18 10:12:00  jjk
//		GCC support.
//
//		Revision 1.1  1998/06/06 15:14:30  jjk
//		Initial revision
//

//		Abstract base class for storage of persistent driver data.
//		Based on sample code provided by Trey Boudreau.

#ifndef ST_PERSISTENTDATA_H
#define ST_PERSISTENTDATA_H

#include <OS.h>

class PersistentData
{
public:
	// Allocate a persistent object for the named device
	// and the given driver version.
	void *operator new(size_t size, const char *pName, int version);

	// Delete a persistent object.  This rarely makes sense.
	void operator delete(void *);
	
protected:
	// Check if the object has been constructed from scratch.
	// Must be called by derived constructors before any
	// member variables are initialized.
	bool NeedsInitialization(void) const
	{
		return mNeedsInitialization;
	}

	// Install a clean-up function which will be called automatically
	// when a new driver version is detected.  The function is passed
	// the old driver version number, which it must use to do its job.
	typedef void (*CleanupFunction)(PersistentData *pSelf, int version);
	void SetCleanupFunction(CleanupFunction f)
	{
		mCleanup = f;
	}
	
private:
	// Persistent storage manipulation.
	static PersistentData *locatePersistentData(const char *pName);
	static PersistentData *createPersistentData(
		size_t size, const char *pName, int version);
	static void releasePersistentData(PersistentData *pData);
	
	// Data members.
	area_id mAreaID;					// ID of area where object is stored
	bool mNeedsInitialization;		// object has been freshly allocated
	int mVersion;						// version of stored object
	CleanupFunction mCleanup;		// clean-up function
};

#endif // ST_PERSISTENTDATA_H
