//		Copyright © 1998–1999  Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
//		$Log: SCSIDefs.h,v $
//		Revision 1.2  1999/04/18 10:13:21  jjk
//		Add LOCATE command.
//
//		Revision 1.1  1998/06/06 15:16:35  jjk
//		Initial revision
//

//		Constants for SCSI commands, status codes etc.

#ifndef ST_SCSIDEFS_H
#define ST_SCSIDEFS_H

//------------------------------------------------------------------------------
// SCSI operation codes.

// GROUP 0
const uint8 SCSI_CMD_TEST_UNIT_READY		 = 0x00; // M all
const uint8 SCSI_CMD_REZERO_UNIT				 = 0x01; // O disk worm rom
const uint8 SCSI_CMD_REWIND					 = 0x01; // M tape
//														 = 0x02; // vendor unique
const uint8 SCSI_CMD_REQUEST_SENSE			 = 0x03; // M all
const uint8 SCSI_CMD_FORMAT_UNIT				 = 0x04; // M disk O prin
const uint8 SCSI_CMD_READ_BLOCK_LIMITS		 = 0x05; // E tape
//														 = 0x06; // vendor unique
const uint8 SCSI_CMD_REASSIGN_BLOCKS		 = 0x07; // O disk worm
const uint8 SCSI_CMD_READ						 = 0x08; // M disk tape O worm rom
const uint8 SCSI_CMD_RECEIVE					 = 0x08; // O proc
const uint8 SCSI_CMD_GET_MESSAGE				 = 0x08; // M comm
//														 = 0x09; // vendor unique
const uint8 SCSI_CMD_WRITE						 = 0x0a; // M disk tape O worm
const uint8 SCSI_CMD_PRINT						 = 0x0a; // M prin
const uint8 SCSI_CMD_SEND						 = 0x0a; // M proc
const uint8 SCSI_CMD_SEND_MESSAGE			 = 0x0a; // M comm
const uint8 SCSI_CMD_SEEK						 = 0x0b; // O disk worm rom
const uint8 SCSI_CMD_TRACK_SELECT			 = 0x0b; // O tape
const uint8 SCSI_CMD_SLEW_AND_PRINT			 = 0x0b; // O prin
//															0x0c..0x0e vendor unique
const uint8 SCSI_CMD_READ_REVERSE			 = 0x0f; // O tape
const uint8 SCSI_CMD_WRITE_FILEMARKS		 = 0x10; // M tape
const uint8 SCSI_CMD_FLUSH_BUFFER			 = 0x10; // M prin
const uint8 SCSI_CMD_SPACE						 = 0x11; // O tape
const uint8 SCSI_CMD_INQUIRY					 = 0x12; // M all
const uint8 SCSI_CMD_VERIFY_0					 = 0x13; // O tape
const uint8 SCSI_CMD_RECOVER_BUFFERED_DATA = 0x14; // O tape prin
const uint8 SCSI_CMD_MODE_SELECT_0			 = 0x15; // O disk tape prin worm rom
const uint8 SCSI_CMD_RESERVE_UNIT			 = 0x16; // O disk tape prin worm rom
const uint8 SCSI_CMD_RELEASE_UNIT			 = 0x17; // O disk tape prin worm rom
const uint8 SCSI_CMD_COPY						 = 0x18; // O all
const uint8 SCSI_CMD_ERASE						 = 0x19; // O tape
const uint8 SCSI_CMD_MODE_SENSE_0			 = 0x1a; // O disk tape prin worm rom
const uint8 SCSI_CMD_START_STOP_UNIT		 = 0x1b; // O disk prin worm rom
const uint8 SCSI_CMD_LOAD_UNLOAD				 = 0x1b; // O tape
const uint8 SCSI_CMD_RECEIVE_DIAG_RESULTS	 = 0x1c; // O all
const uint8 SCSI_CMD_SEND_DIAGNOSTICS		 = 0x1d; // O all
const uint8 SCSI_CMD_PREVENT_ALLOW_REMOVAL = 0x1e; // O disk tape worm rom
//														 = 0x1f; // reserved
// GROUP 1
//															0x20..0x24 vendor unique
const uint8 SCSI_CMD_READ_CAPACITY			 = 0x25; // E disk worm rom
//															0x26..0x27 vendor unique
const uint8 SCSI_CMD_LONG_READ				 = 0x28; // E disk M worm rom
//														 = 0x29; // vendor unique
const uint8 SCSI_CMD_LONG_WRITE				 = 0x2a; // E disk M worm
const uint8 SCSI_CMD_LONG_SEEK				 = 0x2b; // O disk worm rom
const uint8 SCSI_CMD_LOCATE					 = 0x2b; // O tape
//															0x2c..0x2d vendor unique
const uint8 SCSI_CMD_WRITE_AND_VERIFY		 = 0x2e; // O disk worm
const uint8 SCSI_CMD_VERIFY_1					 = 0x2f; // O disk worm rom
const uint8 SCSI_CMD_SEARCH_HIGH				 = 0x30; // O disk worm rom
const uint8 SCSI_CMD_SEARCH_EQUAL			 = 0x31; // O disk worm rom
const uint8 SCSI_CMD_SEARCH_LOW				 = 0x32; // O disk worm rom
const uint8 SCSI_CMD_SET_LIMITS				 = 0x33; // O disk worm rom
const uint8 SCSI_CMD_READ_POSITION			 = 0x34; // O tape
//															0x35..0x36 reserved
const uint8 SCSI_CMD_READ_DEFECT_DATA		 = 0x37; // O disk opti
//														 = 0x38; // reserved
const uint8 SCSI_CMD_COMPARE					 = 0x39; // O all
const uint8 SCSI_CMD_COPY_AND_VERIFY		 = 0x3a; // O all
const uint8 SCSI_CMD_WRITE_BUFFER			 = 0x3b; // O all
const uint8 SCSI_CMD_READ_BUFFER				 = 0x3c; // O all
//															0x3d..0x3f reserved
// GROUP 2
const uint8 SCSI_CMD_CHANGE_DEFINITION		 = 0x40; // O all
//														 = 0x41; // reserved
const uint8 SCSI_CMD_READ_SUBCH				 = 0x42; // O rom
const uint8 SCSI_CMD_READ_TOC					 = 0x43; // O rom
const uint8 SCSI_CMD_READ_HEADER				 = 0x44; // O rom
const uint8 SCSI_CMD_PLAY_AUDIO				 = 0x45; // O rom
const uint8 SCSI_CMD_PLAY_AUDIO_MSF			 = 0x47; // O rom
const uint8 SCSI_CMD_PLAY_AUDIO_TI			 = 0x48; // O rom
const uint8 SCSI_CMD_PLAY_AUDIO_TR			 = 0x49; // O rom
const uint8 SCSI_CMD_PAUSE_RESUME			 = 0x4b; // O rom
const uint8 SCSI_CMD_LOG_SELECT				 = 0x4c; // O all
const uint8 SCSI_CMD_LOG_SENSE				 = 0x4d; // O all
//															0x4e..0x54 reserved
const uint8 SCSI_CMD_MODE_SELECT_2			 = 0x55; // Z
//															0x56..0x59 reserved
const uint8 SCSI_CMD_MODE_SENSE_2			 = 0x5a; // Z
//															0x5b..0x5f reserved
// GROUP 3
//															0x60..0x7f reserved
// GROUP 4
//															0x80..0x9f reserved
// GROUP 5
//															0xa0..0xa4 vendor unique
const uint8 SCSI_CMD_PLAY_AUDIO_LONG		 = 0xa5; // O rom
//											 				0xa6..0xa8 vendor unique
const uint8 SCSI_CMD_PLAY_AUDIO_TR_LONG	 = 0xa9;	// O rom
//															0xaa..0xaf vendor unique
//															0xb0..0xbf reserved
// GROUP 6
//															0xc0..0xdf vendor unique
// GROUP 7
//															0xe0..0xff vendor unique

//------------------------------------------------------------------------------
// Status byte values.

const uint8 SCSI_ST_GOOD								= 0x00;
const uint8 SCSI_ST_CHECK_CONDITION					= 0x02;
const uint8 SCSI_ST_CONDITION_MET					= 0x04;
const uint8 SCSI_ST_BUSY								= 0x08;
const uint8 SCSI_ST_INTERMEDIATE						= 0x10;
const uint8 SCSI_ST_INTERMEDIATE_CONDITION_MET	= 0x14;
const uint8 SCSI_ST_RESERVATION_CONFLICT			= 0x18;
const uint8 SCSI_ST_COMMAND_TERMINATED				= 0x22;
const uint8 SCSI_ST_QUEUE_FULL						= 0x28;

#endif // ST_SCSIDEFS_H
