/*
 *		Copyright © 1998–1999  Jens Kilian
 *
 *		This program is free software; you can redistribute it and/or modify
 *		it under the terms of the GNU General Public License as published by
 *		the Free Software Foundation; either version 1, or (at your option)
 *		any later version.
 *
 *		This program is distributed in the hope that it will be useful,
 *		but WITHOUT ANY WARRANTY; without even the implied warranty of
 *		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
 *		GNU General Public License for more details.
 *
 *		You should have received a copy of the GNU General Public License
 *		along with this program; if not, write to the Free Software
 *		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *		$Log: mtio.h,v $
 *		Revision 1.2  1999/04/18 10:19:51  jjk
 *		Add MTIOCPOS and MTIOCSETPOS.
 *
 *		Revision 1.1  1998/07/04 16:45:43  jjk
 *		Initial revision
 *
 *		Declarations for use with SCSItape driver.
 *
 *		The interface to the driver has been modeled on HP-UX and Linux,
 *		but there is no guarantee of compatibility.
 */

#ifndef ST_MTIO_H
#define ST_MTIO_H

#include <Drivers.h>

enum {		/* Request codes for ioctl(). */
	MTIOCGET		= B_DEVICE_OP_CODES_END + 42,		/* get status			*/
	MTIOCTOP,												/* perform operation */

	MTIOCPOS,												/* get position */
	MTIOCSETPOS,											/* reposition */

	/* Whatever these are, we don't support them (yet?) */
	MTIOCIEOT,
	MTIOCEEOT
};

	/* Structure for MTIOCGET, and macros to decode status. */

struct mtget {
	int32  mt_resid;							/* residual count */
	uint32 mt_gstat;							/* generic status */
	uint32 mt_bsize;							/* current block size */
};

#if __MWERKS__
#  pragma ANSI_strict off
#endif
enum {		/* status flags and fields */
	kFlagBOT			= 0x80000000,
	kFlagEOD			= 0x40000000,
	kFlagEOT			= 0x20000000,
	kFlagEOF			= 0x10000000,
	kFlagSM			= 0x08000000,
	kFlagONL			= 0x04000000,
	kFlagWP			= 0x02000000,
	kFlagCMP			= 0x01000000,
	kDensityMask	= 0x000000ff
};
#if __MWERKS__
#  pragma ANSI_strict reset
#endif

enum {		/* densities (those I could find...) */
	kDensity800bpi		= 0x01,		/* half-inch tapes */
	kDensity1600bpi	= 0x02,
	kDensity6250bpi	= 0x03,

	kDensityDDS1		= 0x13,		/* DDS */
	kDensityDDS2		= 0x24,
	kDensityDDS3		= 0x25,
	kDensityDDS4		= 0x26,

	kDensityQIC11		= 0x04,		/* quarter-inch cartridges */
	kDensityQIC24		= 0x05,
	kDensityQIC120		= 0x0f,
	kDensityQIC150		= 0x10,
	kDensityQIC525		= 0x11,		/* QIC-320? */
	kDensityQIC1350	= 0x12,
	kDensityQIC2100	= 0x1f,
	kDensityQIC2GB		= 0x22,
	kDensityQIC5GB		= 0x28,

	kDensity8mm8200	= 0x14,		/* 8mm */
	kDensity8mm8500	= 0x15
};

#define GMT_BOT(x)		((x&kFlagBOT)!=0)	/* positioned at beginning of tape */
#define GMT_EOD(x)		((x&kFlagEOD)!=0)	/* EOD encountered */
#define GMT_EOT(x)		((x&kFlagEOT)!=0)	/* positioned at end of tape */
#define GMT_EOF(x)		((x&kFlagEOF)!=0)	/* filemark encountered */
#define GMT_SM(x)			((x&kFlagSM)!=0)	/* setmark encountered */
#define GMT_ONLINE(x)	((x&kFlagONL)!=0)	/* drive is online */
#define GMT_WR_PROT(x)	((x&kFlagWP)!=0)	/* media is write protected */
#define GMT_COMPRESS(x)	((x&kFlagCMP)!=0)	/* data compression is in effect */
#define GMT_DENSITY(x)	(x&kDensityMask)	/* media density */

	/* Structure and request codes for MTIOCTOP. */

struct mtop {
	uint32 mt_op;				/* operation - see below */
	int32 mt_count;			/* numeric parameter		 */
};

enum {
	MTWEOF,						/* write filemark					*/
	MTWSS,						/* write setmark					*/
	MTFSR,						/* forward space record			*/
	MTBSR,						/* backward space record		*/
	MTFSF,						/* forward space filemark		*/
	MTBSF,						/* backward space filemark		*/
	MTFSS,						/* forward space setmark		*/
	MTBSS,						/* backward space setmark		*/
	MTEOD,						/* seek to end-of-data			*/
	MTREW,						/* rewind							*/
	MTOFFL,						/* rewind and go offline		*/
	MTRETENS,					/* retension						*/
	MTERASE,						/* erase								*/
	MTSETBSIZ,					/* set block size					*/
	MTNOP,						/* flush write buffers			*/
	
	/* The following requests are not supported and will be ignored. */
	MTCACHE,						/* enable controller cache		*/
	MTNOCACHE					/* disable controller cache	*/
};

	/* Structure for MTIOCPOS and MTIOCSETPOS. */

struct mtpos {
	uint32 mt_blkno;			/* logical block number */
};

#endif /* ST_MTIO_H */
